@@ -139,7 +139,8 @@ class Account(ABC):
         self.account_type = global_common.get_enum_from_value(wise_account.type, AccountType)
         self.user_profile = user_profile
 
-    def transfer(self, recipient: Recipient, receiving_amount: Decimal, to_currency: global_common.Currency, reference: str) -> Transfer:
+    def transfer(self, recipient: Recipient, receiving_amount: Decimal, reference: str = "", to_currency: global_common.Currency = None) -> Transfer:
+        to_currency = self.currency if to_currency is None else to_currency
         transfer: Transfer = Transfer.execute(self.api_key, receiving_amount, recipient, self.currency, to_currency, reference, self.user_profile.type)
 
         if transfer.is_successful:
